@@ -61,6 +61,7 @@
 --------------------------------------------------------------------------- */
 
 #include <localsys.h>
+#include <unistd.h>
 
 /*
 	Miscellaneous.
@@ -81,7 +82,7 @@
 #define	NEVER_TRANSLATE
 #undef	DEFAULT_SMALLBUF
 #endif
-#ifdef  hpux
+#ifdef  __hpux
 #define	WORDSIZE	4
 #define	HALFWORDSIZE	2
 #define	STRLEN_IS_ARG
@@ -95,6 +96,13 @@
 #define	NEVER_TRANSLATE
 #undef	DEFAULT_SMALLBUF
 #endif
+#ifdef	_PPC64
+#define	WORDSIZE	4
+#define	HALFWORDSIZE	2
+#define	STRLEN_IS_ARG
+#define	NEVER_TRANSLATE
+#undef	DEFAULT_SMALLBUF
+#endif
 #ifdef	_IBMR2
 #define	WORDSIZE	4
 #define	HALFWORDSIZE	2
@@ -128,6 +136,12 @@
 #define	STRLEN_IS_ARG
 #undef	DEFAULT_SMALLBUF
 #endif
+#ifdef	__ia64__
+#define	WORDSIZE	4
+#define	HALFWORDSIZE	2
+#define	STRLEN_IS_ARG
+#undef	DEFAULT_SMALLBUF
+#endif
 #ifdef	__ppc__
 #define	WORDSIZE	4
 #define	HALFWORDSIZE	2
@@ -282,7 +296,28 @@ int	_readsb();
 int	_strf2c();
 void	_strlower();
 int	_writeit();
-
+void	sisinlh();
+void	sisinlh5();
+void	sisinth();
+void	sisint1();
+void	sisint3();
+void	sisint5();
+void    siinslh();
+void    siinslh5();
+void    siinst1();
+void    siinst3();
+void    siinst5();
+void	vasinah();
+void	vainsah();
+void	vasincr();
+void	hlhin2s();
+void	hlhs2in();
+void	CTOHF();
+void	CTOHS();
+void	CTOHL();
+void	HTOCF();
+void	HTOCS();
+void	HTOCL();
 
 /*
 	Define the C entry point names.
