@@ -1,5 +1,5 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
@@ -31,8 +31,7 @@ int *nsamp,*iflag, *ierr,*idomain;
 {
     register int i, k;
     double xx, xxs, *depth;
-    float t1,t2,t3,t4,t5;
-    float *pthetao, *th1, *th2;
+    float *pthetao;
     float *pt, *pt1, *pvrmss, *pvrmss1;
     float *pvis, *px, *pvit;
     float *ppv,*ppt,*pppv, *pppt;
@@ -42,8 +41,6 @@ int *nsamp,*iflag, *ierr,*idomain;
 
     static float pid2=1.570796326794897;
     float *vis,*vrmss;
-    int iret,domain;
-    double lvi, div;
     float old_vi;
 
 /*
@@ -53,21 +50,23 @@ int *nsamp,*iflag, *ierr,*idomain;
 */
     depth = (double *)malloc(*nsamp*(sizeof(double)));
     if (depth == NULL) {
-      fprintf(stderr,"attin: ERROR allocating space (%d bytes) in routine crvray\n",*nsamp*(sizeof(double)));
+/*
+      fprintf(stderr,"attin: ERROR allocating space (%d bytes) in routine crvray\n",(int)*nsamp*(sizeof(double)));
+*/
+      fprintf(stderr,"attin: ERROR allocating space (%d bytes) in routine crvray\n",(int)*nsamp*(sizeof(double)));
       exit(1);
       }
     vis = (float *)malloc(*nsamp*(sizeof(float)));
     if (vis == NULL) {
-      fprintf(stderr,"attin: ERROR allocating space (%d bytes) in routine crvray\n",*nsamp*(sizeof(float)));
+      fprintf(stderr,"attin: ERROR allocating space (%d bytes) in routine crvray\n",(int)*nsamp*(sizeof(float)));
       exit(1);
       }
     vrmss = (float *)malloc(*nsamp*(sizeof(float)));
     if (vrmss == NULL) {
-      fprintf(stderr,"attin: ERROR allocating space (%d bytes) in routine crvray\n",*nsamp*(sizeof(float)));
+      fprintf(stderr,"attin: ERROR allocating space (%d bytes) in routine crvray\n",(int)*nsamp*(sizeof(float)));
       exit(1);
       }
 
-    domain=*idomain;
     *ierr = 0; old_vi = vism[0];
 /*========================================*
 |  Create the depth vector for all modes |
@@ -272,7 +271,7 @@ int *n;
     double c1,c2,c3,c4,c5,ddt,ax;
     double xx;
 
-    float *pvi, *pp0, *pt, *pvrms;
+    float *pvi, *pt, *pvrms;
     float *px, *pthetao;
 
     register int i,k;
@@ -404,8 +403,7 @@ int *nsamp,*iflag, *ierr,*idomain;
 {
     register int i, k;
     double xx, xxs, depth[3000];
-    float t1,t2,t3,t4,t5;
-    float *pthetao, *th1, *th2;
+    float *pthetao;
     float *pt, *pt1, *pvrmss, *pvrmss1;
     float *pvis, *px, *v;
     double *pdepth;
@@ -413,8 +411,7 @@ int *nsamp,*iflag, *ierr,*idomain;
 
     static float pid2=1.570796326794897;
     float vis[3000],vrmss[3000], vi[3000], ltheta;
-    int iret;
-    double lvi, div, parm;
+    double div, parm;
     float old_vi;
 
     memcpy(vi,vit,(int)(*nsamp*4));
@@ -530,7 +527,7 @@ int *n;
     double c1,c2,c3,c4,c5,ddt,ax;
     double xx, div;
 
-    float *pvi, *pp0, *pt, *pvrms;
+    float *pvi, *pt, *pvrms;
     float *px, *pthetao, ltheta, parm, *v;
 
     register int i,k;
