@@ -1,20 +1,23 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
 #include <stdio.h>
+#include <stdlib.h>
 #include <localsys.h>
+
 #ifdef LINUXSYSTEM
-#define __USE_XOPEN
+/* #define __USE_XOPEN */
 #include <unistd.h>
 #endif
-#include <sys/wait.h>
+
 #include <sys/types.h>
+#include <sys/wait.h>
 #include <sys/times.h>
 #include <time.h>
 
-void main(argc,argv)
+int main(argc,argv)
 int argc;
 char **argv;
 {
@@ -37,7 +40,9 @@ char **argv;
 	char *address,*subject;
 	char *major_os,*minor_os;
 	char *getenv();
+	char *GetHostName();
 	int  errknt;
+        void conv2DHMS(); 
 
 	start_time=time(NULL);
 	if (pid = fork(), pid == 0) {     /* child process */
@@ -116,21 +121,25 @@ char **argv;
                         argv[1],days,hrs,mins,secs,csdays,cshrs,csmins,cssecs,
                         cudays,cuhrs,cumins,cusecs,exit_status);
 
-#ifdef LINUXSYSTEM
+/* Try using the /usr/lib/sendmail block for 
+ * all architectures - Joe M. Wade 10/31/03
+ */
+
+/* #ifdef LINUXSYSTEM */
 	    sprintf(audit_cmd,"/usr/lib/sendmail %s",address);
 	    mail = popen(audit_cmd,"w");
 	    if (mail != NULL) {
 		fprintf(mail,"To: %s\n",address);
 		fprintf(mail,"From: %s\n",getenv("USER"));
 		fprintf(mail,"Subject: %s\n\n",subject);
-		fprintf(mail,"%s\n",audit_line);
+		fprintf(mail,"\n%s\n",audit_line);
 		fprintf(mail,".\n");
-#else
+/* #else
 	    sprintf(audit_cmd,"Mail -s %s %s",subject,address);
 	    mail = popen(audit_cmd,"w");
 	    if (mail != NULL) {
 		fprintf(mail,"%s\n",audit_line);
-#endif
+ #endif */
 		fclose(mail);
 		}
 	    exit(exit_status);
@@ -141,23 +150,27 @@ char **argv;
 	        minor_os,getenv("USER"),sys_time,date,
                 argv[1],days,hrs,mins,secs,csdays,cshrs,csmins,cssecs,
                 cudays,cuhrs,cumins,cusecs);
+
+/* Try using the /usr/lib/sendmail block for 
+ * all architectures - Joe M. Wade 10/31/03
+ */
 	   
-#ifdef LINUXSYSTEM
+/* #ifdef LINUXSYSTEM */
 	    sprintf(audit_cmd,"/usr/lib/sendmail %s",address);
 	    mail = popen(audit_cmd,"w");
 	    if (mail != NULL) {
 		fprintf(mail,"To: %s\n",address);
 		fprintf(mail,"Subject: %s\n",subject);
 		fprintf(mail,"From: %s\n",getenv("USER"));
-		fprintf(mail,"%s\n",audit_line);
+		fprintf(mail,"\n%s\n",audit_line);
 		fprintf(mail,".\n");
-#else
+/* #else
 
 	   sprintf(audit_cmd,"Mail -s %s %s",subject,address);
 	   mail = popen(audit_cmd,"w");
 	   if (mail != NULL) {
 		fprintf(mail,"%s\n",audit_line);
-#endif
+  #endif */
 		fclose(mail);
 		}
 	  exit(0);
