@@ -8,9 +8,11 @@
 */
 
 #include <localsys.h>
+#include <string.h>
  
 #include "ikp_defines.h"
 #include "ikp_externs.h"
+#include "ikp_remote.h"
 #include "globalE.h"
 
 #ifndef NO_RPC_SUPPORT
@@ -33,12 +35,11 @@ static Widget text=NULL;
 check_load()
 {
   FILE *in;
-  char host_file[1024],name[80];
+  char host_file[1024],name[80],*colon;
   int load[MAX_HOSTS];
   int n,flag,temp;
-#ifndef NO_RPC_SUPPORT
-  struct statstime statp;
-#endif
+  Process statp;
+  int rstat_vals[3];
 
   current_host=0;
 				/* Find .ikp_hosts file in HOME directory. */
@@ -57,21 +58,26 @@ check_load()
     sort_table[host_count]=host_count;
     sscanf(buf1,"%s %f",name,&host_rating[host_count]);
     host_list[host_count]=strdup(name);
-#ifndef NO_RPC_SUPPORT
-    if (rstat(name,&statp)==0) {
-      load[host_count]=(int)statp.avenrun[0]+
-	2*(int)statp.avenrun[1]+10*(int)statp.avenrun[2];
+    memset(&statp,(int) 0,sizeof(Process));
+    statp.prc_host = strdup(name);
+    if (rp_loadavg(&statp,rstat_vals) == 0) {
+      load[host_count]=(int)rstat_vals[0]+
+	(int)(2*rstat_vals[1])+
+	(int)(10*rstat_vals[2]);
       if (load[host_count]==0) {
 	load[host_count]=-1*host_rating[host_count];
       } else {
 	load[host_count]/=host_rating[host_count];
       }
       if (verbose) {
-	fprintf(stderr,"Host %s: ",name);
-	fprintf(stderr,"Load average: %d %d %d  %d\n",
-		(int)statp.avenrun[0],
-		(int)statp.avenrun[1],
-		(int)statp.avenrun[2],load[host_count]);
+	colon = strchr(name,':');
+	if (colon != NULL) *colon = '\0';
+	fprintf(stderr,"Host %-30s: ",name);
+	fprintf(stderr,"Load avg: %5d %5d %5d : %4.2f : %-d\n",
+		rstat_vals[0],
+		rstat_vals[1],
+		rstat_vals[2],
+		host_rating[host_count],load[host_count]);
       }
       host_count++;
       if (host_count>MAX_HOSTS) {
@@ -79,13 +85,10 @@ check_load()
 	return(IKP_FAILURE);
       }
     } else {
-#endif
-      fprintf(stderr,"Warning: can't rstat information from Host: %s\n",
+      fprintf(stderr,"Warning: can't get load average information from Host: %s\n",
 	      name);
       load[host_count]=999;
-#ifndef NO_RPC_SUPPORT
     }
-#endif
   }
 
   host_count--;
@@ -102,7 +105,16 @@ check_load()
       }
     }
   }
-  
+ if (verbose) {
+  fprintf(stderr,"Preferred order:\n");
+  for (n=0; n<=host_count; n++) {
+	  strcpy(name,host_list[sort_table[n]]);
+	  colon = strchr(name,':');
+	  if (colon != NULL) *colon = '\0';
+	  fprintf(stderr,"Host: %-30s Load: %d\n",
+			 name,load[sort_table[n]]);
+    }
+  }
   
   fclose(in);
 }
@@ -241,8 +253,3 @@ void host_listCB(Widget w,
 		NULL);
   
 }
-
-
-
-
-
