@@ -485,6 +485,204 @@ int rp_setup(Process *p)
   return(IKP_SUCCESS);
 }
 
+/*
+   Execute getloadavg() on remote machine.
+*/
+int rp_loadavg(Process *p,int rstat_vals[])
+{
+  struct sockaddr_in caddr;
+  struct hostent *hp;
+  char command;
+  u_long ul;
+  int user_id;
+  char *remuser, *wkdir;
+  struct passwd *pw = NULL;
+  Connector *cnt;
+  struct hostent *gethostbyname();
+  char *log_flag = ":debug";
+  int ikpd_debug;
+
+  if (verbose >= 5)
+      fprintf(stderr,"verbose =  %d\n",verbose);
+  if (p == (Process *) NULL) {
+    ikp_err("Null process.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (p->prc_host == (char *) NULL) {
+    ikp_err("Null hostname.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (strlen(p->prc_host) == 0) {
+    ikp_err("Null hostname.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+
+  if (strcmp(p->prc_host,"*")==0) {
+    if (p->prc_tmp_host!=NULL)
+      free(p->prc_tmp_host);
+    p->prc_tmp_host=strdup(host_list[sort_table[current_host]]);
+    current_host++;
+    if (current_host>host_count)
+      current_host=0;
+
+    if (verbose)
+      fprintf(stderr,"Replace * with host %s\n",p->prc_tmp_host);
+  } else {
+    if (p->prc_tmp_host!=NULL)
+      free(p->prc_tmp_host);
+    p->prc_tmp_host=strdup(p->prc_host);
+  }
+
+/* Added back-door debugging feature activated by appending ":debug" to 
+   the remote host name. This must be stripped before doing the actual
+   connection, though.				- joe m. wade 1/19/96
+*/
+   ikpd_debug = 0;
+   if (strstr(p->prc_tmp_host,log_flag) != NULL) {
+        ikpd_debug = 1;
+        *(p->prc_tmp_host+strlen(p->prc_tmp_host)-strlen(log_flag)) = '\0';
+	}
+
+  /* build address of remote ikpd socket */
+  if ((hp= gethostbyname(p->prc_tmp_host)) == (struct hostent *) NULL) {
+    sprintf(ikp_errbuf, "Host '%s' unknown.", p->prc_tmp_host);
+    ikp_err(ikp_errbuf, NONFATAL);
+    return(IKP_FAILURE);
+  }
+
+  memset((char *) &caddr, 0, sizeof(caddr));
+  memcpy((char *) &caddr.sin_addr, hp->h_addr, hp->h_length);
+  caddr.sin_family= hp->h_addrtype;
+  caddr.sin_port= ikpd_port;
+  
+  /* open control connection to remote ikpd */
+  if ((p->prc_socket= socket(AF_INET, SOCK_STREAM, 0)) == -1) {
+    ikp_err("Socket open error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (connect(p->prc_socket, (struct sockaddr *) &caddr, sizeof(caddr)) < 0) {
+    sprintf(ikp_errbuf, "Cannot connect to host '%s'.", p->prc_tmp_host);
+    ikp_err(ikp_errbuf, NONFATAL);
+    if (close(p->prc_socket) < 0)
+      ikp_err("Socket close error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  p->prc_flags|= PRC_SOCKOPEN;
+  if (verbose >= 5)
+    fprintf(stderr, "rem cntl %d\n", p->prc_socket);
+  
+  /* declare target machine name (needed for alternate addresses ie. fddi) */
+
+  command= IKPRP_HOSTNAME;
+  if (buf_write(p->prc_socket, &command, 1) != 1) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (ikpd_debug == 1)
+	*(p->prc_tmp_host + strlen(p->prc_tmp_host)) = *(char *)log_flag;
+  ul= htonl((u_long) strlen(p->prc_tmp_host));
+  if (buf_write(p->prc_socket, (char *) &ul, sizeof(u_long)) != sizeof(u_long)) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (buf_write(p->prc_socket, p->prc_tmp_host, strlen(p->prc_tmp_host)) != strlen(p->prc_tmp_host)) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (buf_read(p->prc_socket, &command, 1) != 1) {
+    ikp_err("Socket read error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (command != IKPRP_SUCCESS) {
+    sprintf(ikp_errbuf, "Hostname error on host '%s'", p->prc_tmp_host);
+    ikp_err(ikp_errbuf, NONFATAL);
+    return(IKP_FAILURE);
+  }
+
+  /* declare user name */
+  command= IKPRP_USERNAME;
+  if (buf_write(p->prc_socket, &command, 1) != 1) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  user_id= getuid();
+  if ((pw= getpwuid(user_id)) == (struct passwd *) NULL) {
+    ikp_err("Unknown user ID.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  ul= htonl((u_long) strlen(pw->pw_name));
+  if (buf_write(p->prc_socket, (char *) &ul, sizeof(u_long)) != sizeof(u_long)) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (buf_write(p->prc_socket, pw->pw_name, strlen(pw->pw_name)) != strlen(pw->pw_name)) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (p->prc_user == (char *) NULL)
+    remuser= pw->pw_name;
+  else if (strlen(p->prc_user) == 0)
+    remuser= pw->pw_name;
+  else
+    remuser= p->prc_user;
+  ul= htonl((u_long) strlen(remuser));
+  if (buf_write(p->prc_socket, (char *) &ul, sizeof(u_long)) != sizeof(u_long)) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (buf_write(p->prc_socket, remuser, strlen(remuser)) != strlen(remuser)) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (buf_read(p->prc_socket, &command, 1) != 1) {
+    ikp_err("Socket read error.", NONFATAL);
+    return(IKP_FAILURE);
+  }
+  if (command != IKPRP_SUCCESS) {
+    sprintf(ikp_errbuf, "User authentication error on host '%s'.", p->prc_tmp_host);
+    ikp_err(ikp_errbuf, NONFATAL);
+    return(IKP_FAILURE);
+  }
+  
+  command= IKPRP_RSTAT;
+  if (buf_write(p->prc_socket, &command, 1) != 1) {
+    ikp_err("Socket write error.", NONFATAL);
+    return(IKP_FAILURE);
+    }
+
+  if (buf_read(p->prc_socket, (char *) &ul, sizeof(u_long)) != sizeof(u_long)) {
+    ikp_err("Socket read error.", NONFATAL);
+    return(IKP_FAILURE);
+    }
+  rstat_vals[0] = (int) ntohl(ul);
+
+  if (buf_read(p->prc_socket, (char *) &ul, sizeof(u_long)) != sizeof(u_long)) {
+    ikp_err("Socket read error.", NONFATAL);
+    return(IKP_FAILURE);
+    }
+  rstat_vals[1] = (int) ntohl(ul);
+
+  if (buf_read(p->prc_socket, (char *) &ul, sizeof(u_long)) != sizeof(u_long)) {
+    ikp_err("Socket read error.", NONFATAL);
+    return(IKP_FAILURE);
+    }
+  rstat_vals[2] = (int) ntohl(ul);
+
+  if (buf_read(p->prc_socket, &command, 1) != 1) {
+    sprintf(ikp_errbuf, "1. rstat error on host '%s'.", p->prc_tmp_host);
+    ikp_err(ikp_errbuf, NONFATAL);
+    return(IKP_FAILURE);
+    }
+
+  if (command != IKPRP_SUCCESS) {
+    sprintf(ikp_errbuf, "2. rstat error on host '%s'.", p->prc_tmp_host);
+    ikp_err(ikp_errbuf, NONFATAL);
+    return(IKP_FAILURE);
+  }
+  
+  return(IKP_SUCCESS);
+}
+
 /*
    Execute remote process.
 */
@@ -833,7 +1031,7 @@ int rp_localconn(Connector *ct,int *sd)
     setsockopt(*sd,SOL_SOCKET,SO_SNDBUF,&optval,sizeof(int));
     setsockopt(*sd,SOL_SOCKET,SO_RCVBUF,&optval,sizeof(int));
     }
-   if (verbose) {
+   if (verbose >= 2) {
      optval_length = sizeof(int);
      getsockopt(*sd,SOL_SOCKET,SO_SNDBUF,&optval,&optval_length);
      fprintf(stderr,"SO_SNDBUF = %d on socket %d\n",optval,*sd);
