@@ -77,6 +77,9 @@ char *arch= "IRIX64";
 #ifdef __i686__ 
 char *arch= "i686";
 #endif
+#ifdef __ia64__
+char *arch= "ia64";
+#endif
 #ifdef __ppc__		/* Macintosh PowerPC running OS X */
 char *arch= "ppc";
 #endif
@@ -281,8 +284,8 @@ ikpd_setup()
    pointers, etc., and makes/accepts client data socket connections
    to/from other remote daemons. Terminates on any internal error
    or reception of an invalid command over the control socket.
-   Returns when child setup is complete and an IKPRP_EXEC
-   command is received.
+   Returns when child setup is complete and an IKPRP_EXEC or an
+   IKPRP_RSTAT command is received.
 */
 {
 	char command;
@@ -373,6 +376,12 @@ ikpd_setup()
 					ikpd_failure(IKP_PERMISSION);
 				mode= IKPD_EXEC;
 				break;
+			case IKPRP_RSTAT:
+				if (verbose)
+					(void) fprintf(errfp, "RSTAT ACCEPTED\n");
+				ikpd_rstat();
+				mode= IKPD_EXITED;
+				break;
 			case IKPRP_STATUS:
 				ikpd_status();
 				break;
