@@ -3,6 +3,8 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <errno.h>
 #include <pwd.h>
 #include <unistd.h>
@@ -10,9 +12,14 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include <localsys.h>
 #include "ikp_defines.h"
 #include "ikp_remote.h"
 
+#ifndef FSCALE		/* if defined on system, use that */
+#define FSCALE (1 << 8)
+#endif
+
 #ifdef SOLARIS
 #include <fcntl.h>
 #include <sys/socket.h>
@@ -271,6 +278,10 @@ ikpd_username()
 		  (void) fprintf(errfp, "gethostbyaddr failure\n");
 		ikpd_failure(IKP_GETHOSTBYADDR);
 		}
+	else {
+		if (verbose != 0)
+		  fprintf(errfp,"AUTHENTICATION HOST %s\n",hp->h_name);
+		}
 	if (chdir(pw->pw_dir) < 0)
 		ikpd_failure(IKP_CHDIR);
 	if ((fp= fopen(".rhosts", "r")) == (FILE *) NULL)
@@ -1141,3 +1152,59 @@ ikpd_wrdiag()
 	diagbuflen= 0;
 	return;
 }
+void
+ikpd_rstat()
+{
+	int len;
+	u_long ul;
+	char *dir;
+	void ikpd_success(), ikpd_failure();
+	int ivals[3];
+#ifdef HAVE_GETLOADAVG
+	double returnvals[3];
+	getloadavg(returnvals,3);
+#else   /* wrote this hack for machines that don't have getloadavg */
+	FILE *uptime;
+	float returnvals[3];
+	int i;
+	char statusline[128],*strval;
+	uptime = popen("uptime", "r");
+	if (uptime != NULL) {
+		fscanf(uptime,"%127c",statusline);
+		for (i=2; i>=1; i--) {
+		  strval = strrchr(statusline,',');
+		  *strval = '\0';
+		  strval++;
+		  sscanf(strval,"%f",&returnvals[i]);
+		  }
+
+		strval = strrchr(statusline,':');
+		*strval = '\0';
+		strval++;
+		sscanf(strval,"%f",&returnvals[0]);
+	  }
+#endif
+	ivals[0] = returnvals[0] * FSCALE;
+	ivals[1] = returnvals[1] * FSCALE;
+	ivals[2] = returnvals[2] * FSCALE;
+
+	if (verbose) {
+	  fprintf(errfp,"getloadavg: %g %g %g\n",returnvals[0],
+		returnvals[1],returnvals[2]);
+	  fprintf(errfp,"getloadavg: %d %d %d\n",ivals[0],
+		ivals[1],ivals[2]);
+	  }
+	ul= htonl((u_long) ivals[0]);
+	if (buf_write(control, (char *) &ul, sizeof(u_long)) != sizeof(u_long))
+		ikpd_failure(IKP_WRITE);
+	ul= htonl((u_long) ivals[1]);
+	if (buf_write(control, (char *) &ul, sizeof(u_long)) != sizeof(u_long))
+		ikpd_failure(IKP_WRITE);
+	ul= htonl((u_long) ivals[2]);
+	if (buf_write(control, (char *) &ul, sizeof(u_long)) != sizeof(u_long))
+		ikpd_failure(IKP_WRITE);
+
+	ikpd_success();
+	return;
+}
+
