@@ -1,5 +1,5 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
@@ -161,6 +161,15 @@ char **argv;
 
 	do {	/* each call to ARGSTR gives us a new pointer */
 	  value = C_ARGSTR("-map",NULL,"EOF=EOF","EOF=EOF",&argc,argv);
+	  if (strchr(value,'=') == NULL) {
+		fprintf(stderr,"SEGY2USP: ERROR - Illegal mapping specified (%s). Proper format is\n\t\t  -map ToVal=FromVal. If blanks appear",value);
+		fprintf(stderr," within the mapping\n\t\t  specification, the entire string must be quoted.\n\n");
+	        if (verbose == 1) {
+		  fprintf(prtfile,"ERROR - Illegal mapping specified (%s). Proper format is\n\t\t  -map ToVal=FromVal. If blanks appear",value);
+		  fprintf(prtfile," within the mapping\n\t\t  specification, the entire string must be quoted.\n\n");
+		  }
+		exit(100);
+		}
 	  to[indx] = value;
 	  from[indx] = (char *)strchr(to[indx],'=')+1;
 	  to[indx][from[indx]-to[indx]-1] = '\0';
@@ -778,6 +787,13 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 	  memcpy(bufptr,hlh[i],hlh_entry_length);
 	  bufptr+=hlh_entry_length;
 	  }
+/* added check of NumTrc for brain-dead SEGY datasets that caused
+ * scan to hang
+ */
+
+	get_hw_val(header,"NumTrc",LINEHEADER, &lval);
+	if (lval <= 0) 
+	  put_hw_val(header,"NumTrc",LINEHEADER,1);
 
 	put_hw_val(header,"PrcDat",LINEHEADER,cgdate());
 	put_hw_val(header,"HlhEnt",LINEHEADER,hlhknt);
@@ -1099,33 +1115,33 @@ if (errno != 0) {fprintf(stderr,"errno = %d\n",errno); perror("Invalid"); }
 #endif
 		  break;
 		case(3):
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+		  if (native_trace_data != 1) HTOCS(buffer+SEGYTRACEHEADERBYTES,numsmp);
+#endif
 	    	  for (j=0; j<numsmp; j++) {
 			*(float *)(header + SZTRHD + (j*SZSMPD)) = (float)
 			  (*(short *)(buffer+SEGYTRACEHEADERBYTES+
 				(j*sizeof(short))));
 			}
-#if ( BYTE_ORDER == LITTLE_ENDIAN )
-		  if (native_trace_data != 1) HTOCL(header+SZTRHD,numsmp);
-#endif
 		  break;
 		case(2):
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+		  if (native_trace_data != 1) HTOCL(buffer+SEGYTRACEHEADERBYTES,numsmp);
+#endif
 	    	  for (j=0; j<numsmp; j++) 
 			*(float *)(header + SZTRHD + (j*SZSMPD)) = (float)
 			  (*(int *)(buffer+SEGYTRACEHEADERBYTES+
 				(j*sizeof(int))));
-#if ( BYTE_ORDER == LITTLE_ENDIAN )
-		  if (native_trace_data != 1) HTOCL(header+SZTRHD,numsmp);
-#endif
 		  break;
 		case(5):
+#if ( BYTE_ORDER == LITTLE_ENDIAN )
+		  if (native_trace_data != 1) HTOCL(buffer+SEGYTRACEHEADERBYTES,numsmp);
+#endif
 	    	  for (j=0; j<numsmp; j++) {
 			*(float *)(header + SZTRHD + (j*SZSMPD)) = (float)
 			  (*(float *)(buffer+SEGYTRACEHEADERBYTES+
 				(j*sizeof(float))));
 			}
-#if ( BYTE_ORDER == LITTLE_ENDIAN )
-		  if (native_trace_data != 1) HTOCL(header+SZTRHD,numsmp);
-#endif
 	          break;
 		}
 	
