@@ -6,6 +6,8 @@
 /*
 **	home for more built-in functions
 */
+#include <stdio.h>
+#include <stdlib.h>
 #include "ufh.h"
 #include <sys/types.h>
 #include <sys/time.h>
@@ -16,7 +18,6 @@
 #endif
 #include <string.h>
 #include <ctype.h>
-#include <stdio.h>
 
 static int bVector(fs)
 FILE *fs;
@@ -34,7 +35,7 @@ int printItem(fs, tp)
 FILE* fs;
 TPackage tp;
 {
-    int c;
+    int c = 0;
     int i;
     switch(tp.type) {
       case TPackageP:
