@@ -3,6 +3,8 @@
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
+#include <stdio.h>
+#include <stdlib.h>
 #include "ufh.h"
 #include <math.h>
 #include <errno.h>
