@@ -4,6 +4,7 @@
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
 #include <stdio.h>
+#include <stdlib.h>
 #include <ctype.h>
 #include <signal.h>
 #include <setjmp.h>
@@ -71,7 +72,7 @@ char *s;
 char *emalloc(n)        /* check return from malloc */
         unsigned n;
 {
-        char *p, *malloc();
+        char *p;
 
         p = malloc(n);
         if (p == 0)
