@@ -21,6 +21,8 @@ void interruptOnBreak()
 
 #endif
 
+#include <stdio.h>
+#include <stdlib.h>
 #include "ufh.h"
 
 extern int yydebug;
