@@ -1,16 +1,12 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#ifdef USE_SYS_MALLOC
-#include <sys/malloc.h>
-#else
 #include <malloc.h>
-#endif
 #include <localsys.h>
 #include <save.h>
 #include <io_defs.h>
@@ -181,6 +177,15 @@ char **argv;
 
 	do {	/* each call to ARGSTR gives us a new pointer */
 	  value = C_ARGSTR("-map",NULL,"EOF=EOF","EOF=EOF",&argc,argv);
+	  if (strchr(value,'=') == NULL) {
+		fprintf(stderr,"USP2SEGY: ERROR - Illegal mapping specified (%s). Proper format is\n\t\t  -map ToVal=FromVal. If blanks appear",value);
+		fprintf(stderr," within the mapping\n\t\t  specification, the entire string must be quoted.\n\n");
+	        if (verbose == 1) {
+		  fprintf(prtfile,"ERROR - Illegal mapping specified (%s). Proper format is\n\t\t  -map ToVal=FromVal. If blanks appear",value);
+		  fprintf(prtfile," within the mapping\n\t\t  specification, the entire string must be quoted.\n\n");
+		  }
+		exit(100);
+		}
 	  indx++;
 	  to[indx] = value;
 	  from[indx] = (char *)strchr(to[indx],'=')+1;
