@@ -1,5 +1,5 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
@@ -19,8 +19,10 @@ char **argv;
 	char display[256];
 	char *getenv();
 
-	if (argc == 1)
+	if (argc == 1) {
 		dpy = getenv("DISPLAY");
+		if (dpy == NULL) dpy = "";
+		}
 	else if (argc == 2)
 		dpy = argv[1];
 
@@ -28,7 +30,9 @@ char **argv;
 	C_ARGSTR("-display",display,dpy,dpy,&argc,argv);
 
 	if (strlen((char *)display) == 0) {
-		fprintf(stderr,"usage: %s [displayname]\n", argv[0]);
+		fprintf(stderr,"usage: %s [displayname] or\n", argv[0]);
+		fprintf(stderr,"    %s [-display displayname]\n", argv[0]);
+		fprintf(stderr,"\nEnvironment variable DISPLAY is used if it is set\n");
 		exit(1);
 	}
 
