@@ -1,9 +1,9 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
-builtin(name) /* return true if name is /bin/sh built-in */
+int builtin(name) /* return true if name is /bin/sh built-in */
 register char *name;
 {
 	register char **p;
