@@ -1,5 +1,5 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
@@ -20,12 +20,12 @@ getbitmap (toplevel, fn)
    char *fn;
 {
    Arg arg;
-   Pixmap  bitmap;
+   Pixmap  *bitmap;
    unsigned int width,height;
    int x_hot,y_hot;
 
 	if (XReadBitmapFile(XtDisplay(toplevel),XtWindow(toplevel),
-		fn,&width,&height,&bitmap,&x_hot,&y_hot) != 0)
+		fn,&width,&height,bitmap,&x_hot,&y_hot) != 0)
 	    fprintf(stderr, "getbitmap: could not find bitmap: %s\n",fn);
-	return &bitmap;
+	return bitmap;
 }
