@@ -1,5 +1,5 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
@@ -7,22 +7,32 @@
 /* written 09sep90 by Steven Farmer */
 /* revised 08feb91 by Phil Fincannon -- converted to X11R4 Motif */
 /* revised 23jun93 by phil fincannon -- added scrollbar for large panels */
-#include <X11/StringDefs.h>
-#include <X11/Intrinsic.h>
-#include <X11/Shell.h>
-#include <Xm/Xm.h>
-#include <Xm/PushB.h>
-#include <Xm/BulletinB.h>
-#include <Xm/Text.h>
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
+#include <unistd.h>
+#include <malloc.h>
 #include <errno.h>
 
 #include <sys/param.h>
 
+#include <X11/StringDefs.h>
+#include <X11/Intrinsic.h>
+#include <X11/Shell.h>
+#include <Xm/Xm.h>
+#include <Xm/PushB.h>
+#include <Xm/RowColumn.h>
+#include <Xm/ScrolledW.h>
+#include <Xm/BulletinB.h>
+#include <Xm/Text.h>
+
+extern void alert();
+extern void alert_init();
+extern void syserr();
+extern int runcmd(),execcmd();
+
 #ifdef CRAY
 #include <sys/wait.h>
 #define MAXPATHLEN PATH_MAX
@@ -33,7 +43,7 @@
 #define XSET(a,n,v) {Arg *t=&(a); t->name=(n); t->value=(XtArgVal)(v);}
 #define XDEF(str)   XmStringCreateLtoR((str),XmSTRING_DEFAULT_CHARSET)
 
-static XtAppContext context;
+static XtAppContext app_context;
 static Widget shell, form2, form3, scroll, panel, button;
 static Arg arg[19];
 
@@ -42,7 +52,11 @@ static Screen      *scrn;
 static int leaveup = 0, execcheck= 0, leftflag= 0, align = 0;
 static int ac=0, center=0, nrows=0, ncols=0;
 static char *labl[1000], *cmnd[1000];
-extern void chdirCB ();
+extern void chdir_init();
+extern void chdirCB();
+extern int getbutton();
+extern int builtin();
+extern int canexec();
 
 char *help = NULL;
 char *extcmd = NULL;
@@ -74,7 +88,6 @@ main (argc, argv)
    char *argv[];
 {
 
-   extern int  builtin(), canexec();
    extern void seticon(), centermap(), cant(), nozombies();
    extern char *strcntr(), *basename(), *cmdname();
    extern char *optarg;
@@ -102,7 +115,7 @@ main (argc, argv)
    ApplicationData data;
    Pixmap *icon;
 
-   int       width, height;
+   Dimension       width, height;
    Pixmap    pix;
    GC        gc;
    XGCValues values;
@@ -110,8 +123,8 @@ main (argc, argv)
 
 /* initialize the Xt library */
       XtToolkitInitialize ();
-      context = XtCreateApplicationContext ();
-      display = XtOpenDisplay (context, NULL, appnm, classnm,
+      app_context = XtCreateApplicationContext ();
+      display = XtOpenDisplay (app_context, NULL, appnm, classnm,
 			       opts, XtNumber(opts), &argc,argv);
       if (!display) {
 		fprintf(stderr,"%s: can't open display.\n",basename(argv[0]));
@@ -154,7 +167,7 @@ main (argc, argv)
 	 cmnd[nbuttons] = strdup(cmd);
 	 nbuttons++;
       }
-        
+
 SCROLLBAR:
 
 /* initialize row-column widget */
@@ -169,11 +182,12 @@ SCROLLBAR:
                      XmNisAligned,	False,
 /*
                      XmNentryAlignment,
-			leftflag? XmALIGNMENT_BEGINNING : XmALIGNMENT_CENTER,
+			leftflag ? XmALIGNMENT_BEGINNING : XmALIGNMENT_CENTER,
 */
 	   	     NULL);
       opterr = 0;
 
+
 /* add buttons defined in input file */
       for (nn=0; nn<nbuttons; nn++) {
 	 label = labl[nn];
@@ -289,7 +303,7 @@ SCROLLBAR:
 
       centermap (shell); 
 
-      XtAppMainLoop (context);
+      XtAppMainLoop (app_context);
 }
 
 /*------------------------------------------------------------------*/
@@ -298,7 +312,9 @@ void
 cant (cmd)
    char *cmd;
 {
+	/* extern int sys_nerr; */
 	/* extern char *sys_errlist[]; */
+	char *sys_err_string;
 
 	char msg[MAXPATHLEN+MAXMSG];
 
@@ -310,12 +326,13 @@ cant (cmd)
 	strcat (msg, errno > 0 && errno < sys_nerr ?
 		     sys_errlist[errno] : "can't execute.");
 */
-	strcat (msg, errno > 0 ?
-		     strerror(errno) : "can't execute.");
+	sys_err_string = strerror(errno);
+	strcat (msg, errno > 0 && sys_err_string != NULL ?
+		     sys_err_string : "can't execute.");
 /*
 {
 	char *errmsg;
-	if (errno > 0) {
+	if ((errno > 0) && (errno < sys_nerr)) {
 	  errmsg = strerror(errno);
 	  strcat(msg,errmsg);
 	  }
@@ -361,7 +378,7 @@ dismissCB (w, client_data, call_data)
    caddr_t client_data, call_data; 
 {
 	XtUnmapWidget (shell);
-        XtDestroyApplicationContext (context);
+        XtDestroyApplicationContext (app_context);
         exit(0);
 }
 
@@ -369,10 +386,10 @@ dismissCB (w, client_data, call_data)
 
 void
 disarmTO (w, timer)
-   Widget w;
+   XtPointer w;
    XtIntervalId *timer;
 {
-	XtSetSensitive (w, TRUE);
+	XtSetSensitive ((Widget) w, TRUE);
 }
 
 /*------------------------------------------------------------------*/
@@ -422,11 +439,11 @@ runCB (w, client_data, call_data)
 
 	if (leaveup) {
 	    XtSetSensitive (w, FALSE);
-	    timer = XtAppAddTimeOut (context, msec, disarmTO, w);
+	    timer = XtAppAddTimeOut (app_context, msec, disarmTO, w);
 	    istat = runcmd (cmd);
 	} else {
 	    XtUnmapWidget (shell);
-            XtDestroyApplicationContext (context);
+            XtDestroyApplicationContext ((XtAppContext) app_context);
 	    execcmd (cmd);
 	}
 
@@ -445,7 +462,8 @@ void nozombies (sig, code, scp, addr)
    struct sigcontext *scp;
    char *addr;
 */
-void nozombies ()
+void nozombies (signo)
+int signo;
 {
 /*
 	union wait wstatus;
