@@ -1,5 +1,5 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
@@ -36,11 +36,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <ctype.h>
-#ifdef USE_SYS_MALLOC
-#include <sys/malloc.h>
-#else
 #include <malloc.h>
-#endif
 #include <signal.h>
 #include <string.h>
 #include <fcntl.h>
@@ -1193,7 +1189,6 @@ void
 execute (cmd)
    char *cmd;
 {
-   extern int errno;
    int std[2], fd, fdlim;
 
 /*
@@ -1430,7 +1425,6 @@ kill_input (widget, clientdata, calldata)
    XtPointer clientdata, calldata;
 {
 	int waiton();
-	extern int errno;
 	XmString label;
 	Memory  *memory = (Memory *)clientdata;
 
