@@ -1,5 +1,5 @@
 /***********************************************************************
- *                copyright 2001, Amoco Production Company             *
+ *                copyright 2004, Amoco Production Company             *
  *                            All Rights Reserved                      *
  *                    an affiliate of BP America Inc.                  *
  ***********************************************************************/
@@ -24,7 +24,6 @@
 /* 17sep93 phil fincannon - added pick option                  */
 /* 15nov93 phil fincannon - new alert warning for file write er*/
 /* 08dec93 phil fincannon - uppercase keyword option           */
-/* 07aug01 joe m. wade    - upped MAXSEL to 4096               */
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -57,7 +56,7 @@
 #define XSET(a,n,v) {Arg *t=&(a); t->name=(n); t->value=(XtArgVal)(v);}
 #define XDEF(str)   XmStringCreateLtoR((str),XmSTRING_DEFAULT_CHARSET)
 
-#define MAXSEL 4096 /* maximum selection widget entrys + 1 */
+#define MAXSEL 1024 /* maximum selection widget entrys + 1 */
 
 typedef struct { char *iconfile;
                  char *dismiss;
@@ -105,7 +104,6 @@ extern char *trim(), *ljust(), *sp2undr(), *findval();
 /* extern double pow(), atof(); */
 extern int rtckfield();
 
-
 char *envfile = ".explenv";
 char *helpcmd = NULL;
 char filename[300];
@@ -114,10 +112,7 @@ char *item[]={
 "one", "two", "three", "four", "five",
 "one", "two", "three", "four", "five",
 };
-/*
 char *item2[202];
-*/
-char *item2[MAXSEL];	/* changed 1/31/97 - jmw - selectrd could walk out */
 char *selct;
 char *sel[MAXSEL];
 
@@ -199,7 +194,7 @@ updatefields (w) /* update tags array from user input */
 	}
 } /* end updatefields */
 	
-Boolean checkfields(w) /* check every field on panel */
+void checkfields(w) /* check every field on panel */
 Widget w;
 {
 	char *valu, *valu2;
@@ -216,7 +211,7 @@ Widget w;
                XmProcessTraversal (value[i], XmTRAVERSE_CURRENT);
                XtSetSensitive (w, TRUE);
                XmUpdateDisplay (w);
-               return(TRUE);
+               return;
            }
         }
 /* 28aug92 pf+ */
@@ -237,7 +232,7 @@ Widget w;
 	if (!leaveup && rc == 0) exit (NORMALEXIT);
 
         XtSetSensitive (w, TRUE);
-	return(TRUE);
+	return;
 } /* end checkfields */
 
 /* -------------------------------------------------------------------- */
@@ -413,11 +408,7 @@ selectCB (w, i, call_data) /* manage selection box dialog */
    normal_cursor (xpanel);
    /* printf ("selectCB nitems=%d\n", nitems); */
    /* for (m=0; m<nitems; m++) printf ("item2[%d]='%s'\n", m, item2[m]); */
-/*
    for (m=nitems-1; m>=0; m--) XmListAddItem (list, XDEF(item2[m]));
-*/
-/* put things onto the bottom of the list so they're in proper order */
-   for (m=0; m<nitems; m++) XmListAddItem (list, XDEF(item2[m]), 0);
    if (nitems) XtManageChild (dialog[i]);
    /* else	       alert ("selection command failed"); */
    XFlush (XtDisplay(w));
@@ -461,7 +452,7 @@ Widget make_menu_item (item_name, client_data, menu)
 
 /* -------------------------------------------------------------------- */
 
-void main (argc, argv) /* build a panel to view/update explore env file */
+main (argc, argv) /* build a panel to view/update explore env file */
    int argc;
    char **argv;
 {
@@ -737,18 +728,6 @@ void main (argc, argv) /* build a panel to view/update explore env file */
 	       selct = strsav(flist[i]->f_pick);
 	       sel[n++] = (char *)strtok(selct,":");
 	       while (sel[n] = (char *)strtok(NULL,":")) if (n<MAXSEL) n++;
-
-/* code to get the radio box working on Solaris - omitted on switch to X11R6 */
-	       if (flist[i]->f_iniv)
-		   for (m=1; m<n; m++)
-		     if (!strcmp(flist[i]->f_iniv, ljust(sel[m]))) {
-			char *temp;
-			temp = sel[0];
-			sel[0] = sel[m];
-			sel[m] = temp;
-			}
-/* code to get the radio box working on Solaris */
-
 	       for (m=0; m<n; m++) {
 		   sel[m] = trim(ljust(sel[m]));
                    if (!flist[i]->f_iniv)
