@@ -350,11 +350,11 @@ struct sv_globals * globals;
 /*
  * Macros to make writing instructions with correct byte order easier.
  */
-union { short s; char c[2]; } arg;
+union { short s; char c[2]; } uarg;
 #ifdef LITTLE_ENDIAN
-#define	put16(a)    arg.s=a,putc(arg.c[0],sv_fd), putc(arg.c[1],sv_fd)
+#define	put16(a)    uarg.s=a,putc(uarg.c[0],sv_fd), putc(uarg.c[1],sv_fd)
 #else
-#define	put16(a)    arg.s=a,putc(arg.c[1],sv_fd), putc(arg.c[0],sv_fd)
+#define	put16(a)    uarg.s=a,putc(uarg.c[1],sv_fd), putc(uarg.c[0],sv_fd)
 #endif
 
 /* short instructions */
